{% extends 'cosmicdb/base.html' %}

{% load crispy_forms_tags sitetree %}

{% block content %}
    {% block form_header %}
    {% endblock %}
    {% block form_title %}
        <h2>{% sitetree_page_title from "cosmicdb" %}</h2>
    {% endblock %}
    {% block form_breadcrumb %}
        {% sitetree_breadcrumbs from "cosmicdb" template "cosmicdb/breadcrumb.html" %}
    {% endblock %}
    {% block form_content %}
        {% crispy form %}
    {% endblock %}
    {% block form_footer %}
    {% endblock %}    
{% endblock %}
