You're receiving this email because you requested a password reset for your user account at {% load cosmic_tags %}{% get_site_title %}.

Please go to the following page and choose a new password:
{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}
{% endblock %}
Your username, in case you've forgotten:
{{ user.get_username }}

{% get_site_title %}