{% extends 'cosmicdb/base.html' %}

{% load crispy_forms_tags sitetree %}

{% block content %}
    {% block form_header %}
    {% endblock %}
    {% block form_title %}
        <h2>{% sitetree_page_title from "cosmicdb" %}</h2>
    {% endblock %}
    {% block form_breadcrumb %}
        {% sitetree_breadcrumbs from "cosmicdb" template "cosmicdb/breadcrumb.html" %}
    {% endblock %}
    {% block form_content %}
        <form class="ui form" action="" method="post">
            {% csrf_token %}
            <p>Are you sure you want to delete "{{ object }}"?</p>
            <input type="submit" class="ui submit button large red" value="Confirm" />
        </form>
    {% endblock %}
    {% block form_footer %}
    {% endblock %}    
{% endblock %}
